@@ -18,6 +18,7 @@
 #include "eckit/filesystem/PathName.h"
 #include "eckit/io/HandleBuf.h"
 #include "eckit/io/MemoryHandle.h"
+#include "eckit/io/BufferList.h"
 #include "eckit/log/Log.h"
 
 #include "odc/core/DecodeTarget.h"
@@ -42,7 +43,7 @@ namespace api {
 ///
 /// Internal types
 
-class DecoderImpl;
+struct DecoderImpl;
 
 class FrameImpl {
 
@@ -164,26 +165,14 @@ Frame ReaderImpl::next() {
 
 Buffer FrameImpl::encodedData() {
 
-    std::vector<Buffer> buffers;
-    size_t total_size = 0;
+    eckit::BufferList buffers;
+    const bool includeHeader = true;
 
     for (auto& t : tables_) {
-        bool includeHeader = true;
-        buffers.emplace_back(t.readEncodedData(includeHeader));
-        total_size += buffers.back().size();
+        buffers.append(t.readEncodedData(includeHeader));
     }
 
-    if (buffers.size() == 1) {
-        return std::move(buffers.front());
-    }
-
-    Buffer joinedBuffer(total_size);
-    size_t pos = 0;
-
-    for (const auto& b : buffers) {
-        ::memcpy(&joinedBuffer[pos], b, b.size());
-    }
-    return joinedBuffer;
+    return buffers.consolidate();
 }
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -226,6 +215,13 @@ void Decoder::decode(const Frame& frame, size_t nthreads) {
     frame.impl_->decode(*impl_, nthreads);
 }
 
+Decoder Decoder::slice(size_t rowOffset, size_t nrows) const {
+    ASSERT(impl_);
+    core::DecodeTarget&& sliced = impl_->slice(rowOffset, nrows);
+    return {sliced.columns(), sliced.dataFacades()};
+}
+
+
 //----------------------------------------------------------------------------------------------------------------------
 
 SpanVisitor::~SpanVisitor() {}
@@ -431,8 +427,8 @@ public:
         s << "SerialTableReadHandle(" << tables_.size() << ")";
     }
 
-    DataHandle* clone() const {
-        return new SerialTableReadHandle(tables_);
+    DataHandle *clone() const override {
+      return new SerialTableReadHandle(tables_);
     }
 
 private:
@@ -440,8 +436,8 @@ private:
     std::vector<core::Table>& tables_;
 
     Buffer buffer_;
-    long table_;
-    long pos_;
+    size_t table_;
+    size_t pos_;
 };
 }
 
@@ -605,6 +601,7 @@ size_t odbFromCSV(DataHandle& dh_in, DataHandle& dh_out, const std::string& deli
     // Convert data handle to std::istream.
     HandleBuf buf(dh_in);
     std::istream is(&buf);
+    is.exceptions(std::ios_base::badbit);
 
     return odbFromCSV(is, dh_out, delimiter);
 }
@@ -668,8 +665,9 @@ size_t filter(const std::string& sql, eckit::DataHandle& in, eckit::DataHandle&
 
         odc::Writer<> writer(out);
         odc::Writer<>::iterator outit = writer.begin();
-        outit->pass1(it, end);
+        return outit->pass1(it, end);
     }
+    return 0;
 }
 
 //----------------------------------------------------------------------------------------------------------------------
