@@ -25,7 +25,6 @@
 #include "odc/api/Odb.h"
 #include "odc/Comparator.h"
 #include "odc/core/TablesReader.h"
-#include "odc/data/DataHandleFactory.h"
 #include "odc/DispatchingWriter.h"
 #include "odc/ODBAPISettings.h"
 #include "odc/odccapi.h"
@@ -349,29 +348,6 @@ TEST(vector_syntax2)
     eckit::sql::SQLParser::parseString(session, sql);
 }
 
-// DISABLED FOR odb-to-request
-//TEST(blocksSizes)
-//{
-//    size_t numberOfBlocks = 0;
-//    off_t* offsets = 0;
-//    size_t* sizes = 0;
-
-//    int r = get_blocks_offsets("TestFastODA2Request2BIG.odb", &numberOfBlocks, &offsets, &sizes);
-//    ASSERT(r == 0);
-
-//    Log::info() << "num of blocks: " << numberOfBlocks << std::endl;
-//    for (size_t i = 0; i < numberOfBlocks; ++i)
-//    {
-//        Log::info() << "UnitTest: #" << i << ": offset: " << offsets[i] << ", sizes: " << sizes[i] << std::endl;
-//    }
-//    Log::info() << "blocksSizes: numberOfBlocks=" << numberOfBlocks << std::endl;
-//    ASSERT(numberOfBlocks == 5);
-
-//    release_blocks_offsets(&offsets);
-//    release_blocks_sizes(&sizes);
-//}
-
-
 TEST(rownumber1)
 {
 	const char *inputData = "a:INTEGER,b:INTEGER\n" "1,1\n" "2,2\n" "3,3\n" "4,4\n" "5,5\n" "6,6\n" "7,7\n" "8,8\n" "9,9\n" "10,10\n";
@@ -1046,18 +1022,3 @@ TEST(LegacyAPITraverseReaderTwice)
 }
 
 
-//void buildMultiHandle(eckit::MultiHandle&, const std::vector<std::string>&);
-//void buildMultiHandle(eckit::MultiHandle&, const std::string&);
-TEST(HttpHandle)
-{
-    eckit::DataHandle* in (odc::DataHandleFactory::openForRead("http://localhost/conv.odb"));
-    //eckit::DataHandle* out (DataHandleFactory::openForWrite(const std::string&, const eckit::Length& = eckit::Length(0)));
-
-    odc::Select o("select *;", *in);
-
-    for (odc::Select::iterator it (o.begin()); it != o.end(); ++it)
-    {
-        Log::info() << "." << std::endl;
-    }
-}
-
